@@ -1,5 +1,8 @@
 class py_counter():
-    def counter(arr):
+    def __init__(self):
+        return None
+
+    def counter(self,arr):
         '''
         Function that takes in a list or a tuple as an argument and converts it to a hash map that has a (key-value) pair of (element-count of the element's occurrence in the list/tuple).
         '''
